==> openshift-model-6.1.0-sources.jar: io/fabric8/openshift/api/model/RoleBindingRestrictionSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RoleBindingRestrictionSpecFluentImpl<A extends RoleBindingRestrictionSpecFluent<A>> extends BaseFluent<A> implements RoleBindingRestrictionSpecFluent<A>{
  public RoleBindingRestrictionSpecFluentImpl() {
  }
  public RoleBindingRestrictionSpecFluentImpl(RoleBindingRestrictionSpec instance) {
    this.withGrouprestriction(instance.getGrouprestriction()); 
    this.withServiceaccountrestriction(instance.getServiceaccountrestriction()); 
    this.withUserrestriction(instance.getUserrestriction()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private GroupRestrictionBuilder grouprestriction;
  private ServiceAccountRestrictionBuilder serviceaccountrestriction;
  private UserRestrictionBuilder userrestriction;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildGrouprestriction instead.
   * @return The buildable object.
   */
  @Deprecated
  public GroupRestriction getGrouprestriction() {
    return this.grouprestriction!=null ?this.grouprestriction.build():null;
  }
  public GroupRestriction buildGrouprestriction() {
    return this.grouprestriction!=null ?this.grouprestriction.build():null;
  }
  public A withGrouprestriction(GroupRestriction grouprestriction) {
    _visitables.get("grouprestriction").remove(this.grouprestriction);
    if (grouprestriction!=null){ this.grouprestriction= new GroupRestrictionBuilder(grouprestriction); _visitables.get("grouprestriction").add(this.grouprestriction);} else { this.grouprestriction = null; _visitables.get("grouprestriction").remove(this.grouprestriction); } return (A) this;
  }
  public Boolean hasGrouprestriction() {
    return this.grouprestriction != null;
  }
  public RoleBindingRestrictionSpecFluent.GrouprestrictionNested<A> withNewGrouprestriction() {
    return new RoleBindingRestrictionSpecFluentImpl.GrouprestrictionNestedImpl();
  }
  public RoleBindingRestrictionSpecFluent.GrouprestrictionNested<A> withNewGrouprestrictionLike(GroupRestriction item) {
    return new RoleBindingRestrictionSpecFluentImpl.GrouprestrictionNestedImpl(item);
  }
  public RoleBindingRestrictionSpecFluent.GrouprestrictionNested<A> editGrouprestriction() {
    return withNewGrouprestrictionLike(getGrouprestriction());
  }
  public RoleBindingRestrictionSpecFluent.GrouprestrictionNested<A> editOrNewGrouprestriction() {
    return withNewGrouprestrictionLike(getGrouprestriction() != null ? getGrouprestriction(): new GroupRestrictionBuilder().build());
  }
  public RoleBindingRestrictionSpecFluent.GrouprestrictionNested<A> editOrNewGrouprestrictionLike(GroupRestriction item) {
    return withNewGrouprestrictionLike(getGrouprestriction() != null ? getGrouprestriction(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildServiceaccountrestriction instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceAccountRestriction getServiceaccountrestriction() {
    return this.serviceaccountrestriction!=null ?this.serviceaccountrestriction.build():null;
  }
  public ServiceAccountRestriction buildServiceaccountrestriction() {
    return this.serviceaccountrestriction!=null ?this.serviceaccountrestriction.build():null;
  }
  public A withServiceaccountrestriction(ServiceAccountRestriction serviceaccountrestriction) {
    _visitables.get("serviceaccountrestriction").remove(this.serviceaccountrestriction);
    if (serviceaccountrestriction!=null){ this.serviceaccountrestriction= new ServiceAccountRestrictionBuilder(serviceaccountrestriction); _visitables.get("serviceaccountrestriction").add(this.serviceaccountrestriction);} else { this.serviceaccountrestriction = null; _visitables.get("serviceaccountrestriction").remove(this.serviceaccountrestriction); } return (A) this;
  }
  public Boolean hasServiceaccountrestriction() {
    return this.serviceaccountrestriction != null;
  }
  public RoleBindingRestrictionSpecFluent.ServiceaccountrestrictionNested<A> withNewServiceaccountrestriction() {
    return new RoleBindingRestrictionSpecFluentImpl.ServiceaccountrestrictionNestedImpl();
  }
  public RoleBindingRestrictionSpecFluent.ServiceaccountrestrictionNested<A> withNewServiceaccountrestrictionLike(ServiceAccountRestriction item) {
    return new RoleBindingRestrictionSpecFluentImpl.ServiceaccountrestrictionNestedImpl(item);
  }
  public RoleBindingRestrictionSpecFluent.ServiceaccountrestrictionNested<A> editServiceaccountrestriction() {
    return withNewServiceaccountrestrictionLike(getServiceaccountrestriction());
  }
  public RoleBindingRestrictionSpecFluent.ServiceaccountrestrictionNested<A> editOrNewServiceaccountrestriction() {
    return withNewServiceaccountrestrictionLike(getServiceaccountrestriction() != null ? getServiceaccountrestriction(): new ServiceAccountRestrictionBuilder().build());
  }
  public RoleBindingRestrictionSpecFluent.ServiceaccountrestrictionNested<A> editOrNewServiceaccountrestrictionLike(ServiceAccountRestriction item) {
    return withNewServiceaccountrestrictionLike(getServiceaccountrestriction() != null ? getServiceaccountrestriction(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildUserrestriction instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserRestriction getUserrestriction() {
    return this.userrestriction!=null ?this.userrestriction.build():null;
  }
  public UserRestriction buildUserrestriction() {
    return this.userrestriction!=null ?this.userrestriction.build():null;
  }
  public A withUserrestriction(UserRestriction userrestriction) {
    _visitables.get("userrestriction").remove(this.userrestriction);
    if (userrestriction!=null){ this.userrestriction= new UserRestrictionBuilder(userrestriction); _visitables.get("userrestriction").add(this.userrestriction);} else { this.userrestriction = null; _visitables.get("userrestriction").remove(this.userrestriction); } return (A) this;
  }
  public Boolean hasUserrestriction() {
    return this.userrestriction != null;
  }
  public RoleBindingRestrictionSpecFluent.UserrestrictionNested<A> withNewUserrestriction() {
    return new RoleBindingRestrictionSpecFluentImpl.UserrestrictionNestedImpl();
  }
  public RoleBindingRestrictionSpecFluent.UserrestrictionNested<A> withNewUserrestrictionLike(UserRestriction item) {
    return new RoleBindingRestrictionSpecFluentImpl.UserrestrictionNestedImpl(item);
  }
  public RoleBindingRestrictionSpecFluent.UserrestrictionNested<A> editUserrestriction() {
    return withNewUserrestrictionLike(getUserrestriction());
  }
  public RoleBindingRestrictionSpecFluent.UserrestrictionNested<A> editOrNewUserrestriction() {
    return withNewUserrestrictionLike(getUserrestriction() != null ? getUserrestriction(): new UserRestrictionBuilder().build());
  }
  public RoleBindingRestrictionSpecFluent.UserrestrictionNested<A> editOrNewUserrestrictionLike(UserRestriction item) {
    return withNewUserrestrictionLike(getUserrestriction() != null ? getUserrestriction(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RoleBindingRestrictionSpecFluentImpl that = (RoleBindingRestrictionSpecFluentImpl) o;
    if (grouprestriction != null ? !grouprestriction.equals(that.grouprestriction) :that.grouprestriction != null) return false;
    if (serviceaccountrestriction != null ? !serviceaccountrestriction.equals(that.serviceaccountrestriction) :that.serviceaccountrestriction != null) return false;
    if (userrestriction != null ? !userrestriction.equals(that.userrestriction) :that.userrestriction != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(grouprestriction,  serviceaccountrestriction,  userrestriction,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (grouprestriction != null) { sb.append("grouprestriction:"); sb.append(grouprestriction + ","); }
    if (serviceaccountrestriction != null) { sb.append("serviceaccountrestriction:"); sb.append(serviceaccountrestriction + ","); }
    if (userrestriction != null) { sb.append("userrestriction:"); sb.append(userrestriction + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class GrouprestrictionNestedImpl<N> extends GroupRestrictionFluentImpl<RoleBindingRestrictionSpecFluent.GrouprestrictionNested<N>> implements RoleBindingRestrictionSpecFluent.GrouprestrictionNested<N>,Nested<N>{
    GrouprestrictionNestedImpl(GroupRestriction item) {
      this.builder = new GroupRestrictionBuilder(this, item);
    }
    GrouprestrictionNestedImpl() {
      this.builder = new GroupRestrictionBuilder(this);
    }
    GroupRestrictionBuilder builder;
    public N and() {
      return (N) RoleBindingRestrictionSpecFluentImpl.this.withGrouprestriction(builder.build());
    }
    public N endGrouprestriction() {
      return and();
    }
    
  }
  class ServiceaccountrestrictionNestedImpl<N> extends ServiceAccountRestrictionFluentImpl<RoleBindingRestrictionSpecFluent.ServiceaccountrestrictionNested<N>> implements RoleBindingRestrictionSpecFluent.ServiceaccountrestrictionNested<N>,Nested<N>{
    ServiceaccountrestrictionNestedImpl(ServiceAccountRestriction item) {
      this.builder = new ServiceAccountRestrictionBuilder(this, item);
    }
    ServiceaccountrestrictionNestedImpl() {
      this.builder = new ServiceAccountRestrictionBuilder(this);
    }
    ServiceAccountRestrictionBuilder builder;
    public N and() {
      return (N) RoleBindingRestrictionSpecFluentImpl.this.withServiceaccountrestriction(builder.build());
    }
    public N endServiceaccountrestriction() {
      return and();
    }
    
  }
  class UserrestrictionNestedImpl<N> extends UserRestrictionFluentImpl<RoleBindingRestrictionSpecFluent.UserrestrictionNested<N>> implements RoleBindingRestrictionSpecFluent.UserrestrictionNested<N>,Nested<N>{
    UserrestrictionNestedImpl(UserRestriction item) {
      this.builder = new UserRestrictionBuilder(this, item);
    }
    UserrestrictionNestedImpl() {
      this.builder = new UserRestrictionBuilder(this);
    }
    UserRestrictionBuilder builder;
    public N and() {
      return (N) RoleBindingRestrictionSpecFluentImpl.this.withUserrestriction(builder.build());
    }
    public N endUserrestriction() {
      return and();
    }
    
  }
  
}

==> openshift-model-6.7.0-sources.jar: io/fabric8/openshift/api/model/RoleBindingRestrictionSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RoleBindingRestrictionSpecFluentImpl<A extends RoleBindingRestrictionSpecFluent<A>> extends BaseFluent<A> implements RoleBindingRestrictionSpecFluent<A>{
  public RoleBindingRestrictionSpecFluentImpl() {
  }
  public RoleBindingRestrictionSpecFluentImpl(RoleBindingRestrictionSpec instance) {
    if (instance != null) {
      this.withGrouprestriction(instance.getGrouprestriction());
      this.withServiceaccountrestriction(instance.getServiceaccountrestriction());
      this.withUserrestriction(instance.getUserrestriction());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private GroupRestrictionBuilder grouprestriction;
  private ServiceAccountRestrictionBuilder serviceaccountrestriction;
  private UserRestrictionBuilder userrestriction;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildGrouprestriction instead.
   * @return The buildable object.
   */
  @Deprecated
  public GroupRestriction getGrouprestriction() {
    return this.grouprestriction!=null ?this.grouprestriction.build():null;
  }
  public GroupRestriction buildGrouprestriction() {
    return this.grouprestriction!=null ?this.grouprestriction.build():null;
  }
  public A withGrouprestriction(GroupRestriction grouprestriction) {
    _visitables.get("grouprestriction").remove(this.grouprestriction);
    if (grouprestriction!=null){ this.grouprestriction= new GroupRestrictionBuilder(grouprestriction); _visitables.get("grouprestriction").add(this.grouprestriction);} else { this.grouprestriction = null; _visitables.get("grouprestriction").remove(this.grouprestriction); } return (A) this;
  }
  public Boolean hasGrouprestriction() {
    return this.grouprestriction != null;
  }
  public RoleBindingRestrictionSpecFluentImpl.GrouprestrictionNested<A> withNewGrouprestriction() {
    return new RoleBindingRestrictionSpecFluentImpl.GrouprestrictionNestedImpl();
  }
  public RoleBindingRestrictionSpecFluentImpl.GrouprestrictionNested<A> withNewGrouprestrictionLike(GroupRestriction item) {
    return new RoleBindingRestrictionSpecFluentImpl.GrouprestrictionNestedImpl(item);
  }
  public RoleBindingRestrictionSpecFluentImpl.GrouprestrictionNested<A> editGrouprestriction() {
    return withNewGrouprestrictionLike(getGrouprestriction());
  }
  public RoleBindingRestrictionSpecFluentImpl.GrouprestrictionNested<A> editOrNewGrouprestriction() {
    return withNewGrouprestrictionLike(getGrouprestriction() != null ? getGrouprestriction(): new GroupRestrictionBuilder().build());
  }
  public RoleBindingRestrictionSpecFluentImpl.GrouprestrictionNested<A> editOrNewGrouprestrictionLike(GroupRestriction item) {
    return withNewGrouprestrictionLike(getGrouprestriction() != null ? getGrouprestriction(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildServiceaccountrestriction instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceAccountRestriction getServiceaccountrestriction() {
    return this.serviceaccountrestriction!=null ?this.serviceaccountrestriction.build():null;
  }
  public ServiceAccountRestriction buildServiceaccountrestriction() {
    return this.serviceaccountrestriction!=null ?this.serviceaccountrestriction.build():null;
  }
  public A withServiceaccountrestriction(ServiceAccountRestriction serviceaccountrestriction) {
    _visitables.get("serviceaccountrestriction").remove(this.serviceaccountrestriction);
    if (serviceaccountrestriction!=null){ this.serviceaccountrestriction= new ServiceAccountRestrictionBuilder(serviceaccountrestriction); _visitables.get("serviceaccountrestriction").add(this.serviceaccountrestriction);} else { this.serviceaccountrestriction = null; _visitables.get("serviceaccountrestriction").remove(this.serviceaccountrestriction); } return (A) this;
  }
  public Boolean hasServiceaccountrestriction() {
    return this.serviceaccountrestriction != null;
  }
  public RoleBindingRestrictionSpecFluentImpl.ServiceaccountrestrictionNested<A> withNewServiceaccountrestriction() {
    return new RoleBindingRestrictionSpecFluentImpl.ServiceaccountrestrictionNestedImpl();
  }
  public RoleBindingRestrictionSpecFluentImpl.ServiceaccountrestrictionNested<A> withNewServiceaccountrestrictionLike(ServiceAccountRestriction item) {
    return new RoleBindingRestrictionSpecFluentImpl.ServiceaccountrestrictionNestedImpl(item);
  }
  public RoleBindingRestrictionSpecFluentImpl.ServiceaccountrestrictionNested<A> editServiceaccountrestriction() {
    return withNewServiceaccountrestrictionLike(getServiceaccountrestriction());
  }
  public RoleBindingRestrictionSpecFluentImpl.ServiceaccountrestrictionNested<A> editOrNewServiceaccountrestriction() {
    return withNewServiceaccountrestrictionLike(getServiceaccountrestriction() != null ? getServiceaccountrestriction(): new ServiceAccountRestrictionBuilder().build());
  }
  public RoleBindingRestrictionSpecFluentImpl.ServiceaccountrestrictionNested<A> editOrNewServiceaccountrestrictionLike(ServiceAccountRestriction item) {
    return withNewServiceaccountrestrictionLike(getServiceaccountrestriction() != null ? getServiceaccountrestriction(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildUserrestriction instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserRestriction getUserrestriction() {
    return this.userrestriction!=null ?this.userrestriction.build():null;
  }
  public UserRestriction buildUserrestriction() {
    return this.userrestriction!=null ?this.userrestriction.build():null;
  }
  public A withUserrestriction(UserRestriction userrestriction) {
    _visitables.get("userrestriction").remove(this.userrestriction);
    if (userrestriction!=null){ this.userrestriction= new UserRestrictionBuilder(userrestriction); _visitables.get("userrestriction").add(this.userrestriction);} else { this.userrestriction = null; _visitables.get("userrestriction").remove(this.userrestriction); } return (A) this;
  }
  public Boolean hasUserrestriction() {
    return this.userrestriction != null;
  }
  public RoleBindingRestrictionSpecFluentImpl.UserrestrictionNested<A> withNewUserrestriction() {
    return new RoleBindingRestrictionSpecFluentImpl.UserrestrictionNestedImpl();
  }
  public RoleBindingRestrictionSpecFluentImpl.UserrestrictionNested<A> withNewUserrestrictionLike(UserRestriction item) {
    return new RoleBindingRestrictionSpecFluentImpl.UserrestrictionNestedImpl(item);
  }
  public RoleBindingRestrictionSpecFluentImpl.UserrestrictionNested<A> editUserrestriction() {
    return withNewUserrestrictionLike(getUserrestriction());
  }
  public RoleBindingRestrictionSpecFluentImpl.UserrestrictionNested<A> editOrNewUserrestriction() {
    return withNewUserrestrictionLike(getUserrestriction() != null ? getUserrestriction(): new UserRestrictionBuilder().build());
  }
  public RoleBindingRestrictionSpecFluentImpl.UserrestrictionNested<A> editOrNewUserrestrictionLike(UserRestriction item) {
    return withNewUserrestrictionLike(getUserrestriction() != null ? getUserrestriction(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RoleBindingRestrictionSpecFluentImpl that = (RoleBindingRestrictionSpecFluentImpl) o;
    if (!java.util.Objects.equals(grouprestriction, that.grouprestriction)) return false;

    if (!java.util.Objects.equals(serviceaccountrestriction, that.serviceaccountrestriction)) return false;

    if (!java.util.Objects.equals(userrestriction, that.userrestriction)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(grouprestriction,  serviceaccountrestriction,  userrestriction,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (grouprestriction != null) { sb.append("grouprestriction:"); sb.append(grouprestriction + ","); }
    if (serviceaccountrestriction != null) { sb.append("serviceaccountrestriction:"); sb.append(serviceaccountrestriction + ","); }
    if (userrestriction != null) { sb.append("userrestriction:"); sb.append(userrestriction + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class GrouprestrictionNestedImpl<N> extends GroupRestrictionFluentImpl<RoleBindingRestrictionSpecFluentImpl.GrouprestrictionNested<N>> implements RoleBindingRestrictionSpecFluentImpl.GrouprestrictionNested<N>,Nested<N>{
    GrouprestrictionNestedImpl(GroupRestriction item) {
      this.builder = new GroupRestrictionBuilder(this, item);
    }
    GrouprestrictionNestedImpl() {
      this.builder = new GroupRestrictionBuilder(this);
    }
    GroupRestrictionBuilder builder;
    public N and() {
      return (N) RoleBindingRestrictionSpecFluentImpl.this.withGrouprestriction(builder.build());
    }
    public N endGrouprestriction() {
      return and();
    }
    
  }
  class ServiceaccountrestrictionNestedImpl<N> extends ServiceAccountRestrictionFluentImpl<RoleBindingRestrictionSpecFluentImpl.ServiceaccountrestrictionNested<N>> implements RoleBindingRestrictionSpecFluentImpl.ServiceaccountrestrictionNested<N>,Nested<N>{
    ServiceaccountrestrictionNestedImpl(ServiceAccountRestriction item) {
      this.builder = new ServiceAccountRestrictionBuilder(this, item);
    }
    ServiceaccountrestrictionNestedImpl() {
      this.builder = new ServiceAccountRestrictionBuilder(this);
    }
    ServiceAccountRestrictionBuilder builder;
    public N and() {
      return (N) RoleBindingRestrictionSpecFluentImpl.this.withServiceaccountrestriction(builder.build());
    }
    public N endServiceaccountrestriction() {
      return and();
    }
    
  }
  class UserrestrictionNestedImpl<N> extends UserRestrictionFluentImpl<RoleBindingRestrictionSpecFluentImpl.UserrestrictionNested<N>> implements RoleBindingRestrictionSpecFluentImpl.UserrestrictionNested<N>,Nested<N>{
    UserrestrictionNestedImpl(UserRestriction item) {
      this.builder = new UserRestrictionBuilder(this, item);
    }
    UserrestrictionNestedImpl() {
      this.builder = new UserRestrictionBuilder(this);
    }
    UserRestrictionBuilder builder;
    public N and() {
      return (N) RoleBindingRestrictionSpecFluentImpl.this.withUserrestriction(builder.build());
    }
    public N endUserrestriction() {
      return and();
    }
    
  }
  
}
